===================================================
BTC Template Tables
===================================================

Some classes for for describing tables with an auto-generated template.

Detailed documentation is in the "docs" directory.

Quick start
-----------

No description yet